@@ -1,7 +1,8 @@
 # coding: utf8
-import pytest
 import sys
 
+import pytest
+
 from atlassian import ServiceDesk
 
 SERVICEDESK = None
@@ -25,6 +26,10 @@ class TestBasic:
         result = [x["name"] for x in SERVICEDESK.get_organisations()["values"]]
         assert result == ["Charlie Cakes Franchises"], "Result of [get_organisations()]"
 
+    def test_get_organizations(self):
+        result = [x["name"] for x in SERVICEDESK.get_organizations()["values"]]
+        assert result == ["Charlie Cakes Franchises"], "Result of [get_organizations()]"
+
     def test_get_organisations_servicedesk_id(self):
         result = [x["name"] for x in SERVICEDESK.get_organisations(service_desk_id="{serviceDeskId}")["values"]]
         assert result == [
@@ -33,6 +38,14 @@ class TestBasic:
             "The Adjustment Bureau",
         ], "Result of [get_organisations(service_desk_id)]"
 
+    def test_get_organizations_servicedesk_id(self):
+        result = [x["name"] for x in SERVICEDESK.get_organizations(service_desk_id="{serviceDeskId}")["values"]]
+        assert result == [
+            "Charlie Cakes Franchises",
+            "Atlas Coffee Co",
+            "The Adjustment Bureau",
+        ], "Result of [get_organizations(service_desk_id)]"
+
     def test_get_organization(self):
         result = SERVICEDESK.get_organization("{organizationId}")
         assert result["name"] == "Charlie Cakes Franchises", "Result of [test_get_organization(...)]"
